@@ -1,10 +1,10 @@
 estGStar <-
-function(data, cutoff = 0.5){
+function(data){
 if(missing(data))
 stop("data is missing.")
 
 mean <- rowSums(data)/ncol(data)
-gstar <- 1*(mean > cutoff)
+gstar <- 1*(mean > .5)
 
 return(gstar)
 }
